#include "Zeus_template.hh"

#include "Rivet/RivetAIDA.hh"

//Only needed if we access the handler for e.g. the number of events analysed
#include "Rivet/AnalysisHandler.hh"

//not necessary for a wworking analysis, but gives access to nicer logging output
#include "Rivet/Tools/Logging.hh"


namespace Rivet{
  
  //the init method usually just sets up the histograms
  
  void Zeus_template::init(){
    //Ideally would use the autobooking feature (see wiki).  Since this paper is not
    // in hepdata we make up some bins
    _histo = bookHistogram1D("JetET", "Jet ET", 150, 0.0, 150.0);
    return;
  }

  //the analyze method runs the analysis
  
  void Zeus_template::analyze(const Event &evt){
    
    const JacquetBlondelY &yjb = applyProjection<JacquetBlondelY>(evt, "YJB");
    //                                                    the string here ^^^ is the
    //                                                    same as used in the constructor
    
    
    const FastJets &jetproj = applyProjection<FastJets>(evt, "KT1Jets");
    
    double y = yjb.y();
    
    //get jets above 6 GeV
    Jets allJets = jetproj.jets(6.0 * GeV);
    
    Jets validJets;
    
    //select jets inside eta<2.5
    for(Jets::const_iterator jet = allJets.begin();
        jet != allJets.end(); ++jet){
     
      double eta = jet->momentum().pseudorapidity();
      if(eta > -2.5 && eta < 2.5){
        validJets.push_back(*jet);
      }
    }
    
    if(!(y > 0.2 && y < 0.85 && validJets.size() > 2)){
      
      //this removes the event from the calculation of the cross section
      vetoEvent(evt);
      return;
    }
    
    //if we get here then the event passes the (rough) selection and we plot the inclusive ET
    
    for(Jets::const_iterator jet = validJets.begin();
        jet != validJets.end(); ++jet){
      _histo->fill(jet->momentum().Et());
    }
  
    return;
  }
  
  // in the finalize method we normalise the histograms if necessary
  void Zeus_template::finalize(){
    
    //handler.sumOfWeights() is the sum of all event weights generated
    float xsecPerEvent = crossSection() / handler().sumOfWeights();
    scale(_histo, xsecPerEvent);
    return;
  }
  
}
